# Dock8r

CLI implementing subset of Docker commands to run containers in K8s.

-   Free software: MIT license

## Features

-   `docker ps`
-   `docker run` - `-v` flag
-   `docker exec` - `-i` flag
-   `docker stop`

## Architecture

![](Dock8r.png)

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [`audreyr/cookiecutter-pypackage`](https://github.com/audreyr/cookiecutter-pypackage) project template.

Inspired by https://kubernetes.io/docs/reference/kubectl/docker-cli-to-kubectl/
